@@ -22,14 +22,11 @@
 
 
 
-//Include Prototypes
-#include "headers/greaddata.h"
-
 //Geeks Read Data (Function)
-int GReadData(FILE *GIOD,int GNNum)
+int GReadData()
 
 {
-
+/*
     //Variables
     int i,j;
     int GANNType,GNeurons,GNInputs;
@@ -115,7 +112,7 @@ int GReadData(FILE *GIOD,int GNNum)
     
     //Close GKDB
     fclose(FileToOpen);
-
+*/
 }
 
 /* ------------------------------------------------------------------------ */
