@@ -22,9 +22,6 @@
 
 
 
-//Include Prototypes
-#include "headers/gsleep.h"
-
 //Geeks Sleep (Function)
 void GSleep(int Sec)
 
